@@ -65,9 +65,7 @@ class TestExperimentServerIntegration(IBMTestCase):
             token=os.getenv("QISKIT_IBM_STAGING_API_TOKEN"),
             url=os.getenv("QISKIT_IBM_STAGING_API_URL"),
         )
-        cls.backend = least_busy(
-            cls.provider.backends(simulator=False, min_num_qubits=5)
-        )
+        cls.backend = least_busy(cls.provider.backends())
 
     @classmethod
     def get_experiments(cls, **kwargs):
@@ -1338,6 +1336,7 @@ class TestExperimentServerIntegration(IBMTestCase):
         file_list = self.service.files(exp_id)["files"]
         self.assertEqual(len(file_list), 1)
         self.assertEqual(file_list[0]["Key"], filename + ".json")
+        self.assertTrue(self.service.experiment_has_file(exp_id, filename + ".json"))
 
         # updating existing file
         data = {"string": "a-string", "int": 89, "float": 2.71, "null": None}
